@@ -17,15 +17,15 @@
 
 
 import re
-from abc import abstractmethod
 from datetime import date
 from pathlib import Path
-from typing import Dict, List, Optional, Protocol, Union, runtime_checkable
+from typing import Dict, List, Optional, Union
 
 import tomlkit
 
 from pontos.changelog.errors import ChangelogBuilderError
 from pontos.git import Git
+from pontos.typing import SupportsStr
 
 ADDRESS = "https://github.com/"
 
@@ -34,17 +34,11 @@ DEFAULT_CHANGELOG_CONFIG = """commit_types = [
     { message = "^remove", group = "Removed"},
     { message = "^change", group = "Changed"},
     { message = "^fix", group = "Bug Fixes"},
+    { message = "^deps", group = "Dependencies"},
 ]
 """
 
 
-@runtime_checkable
-class SupportsStr(Protocol):
-    @abstractmethod
-    def __str__(self) -> str:
-        pass
-
-
 class ChangelogBuilder:
     """
     Creates Changelog from conventional commits using the git log
@@ -59,8 +53,10 @@ class ChangelogBuilder:
             from pontos.changelog import ChangelogBuilder
 
             builder = ChangelogBuilder(space="my-org", project="my-project)
-            changelog = builder.create_changelog
-                last_version="1.2.3", next_version="2.0.0")
+            changelog = builder.create_changelog(
+                last_version="1.2.3",
+                next_version="2.0.0",
+            )
     """
 
     def __init__(
