@@ -19,9 +19,10 @@ import subprocess
 from enum import Enum
 from os import PathLike, fspath
 from pathlib import Path
-from typing import List, Optional, Union
+from typing import Iterable, Iterator, List, Optional, Union
 
 from pontos.errors import PontosError
+from pontos.git.status import StatusEntry, parse_git_status
 
 DEFAULT_TAG_SORT_SUFFIX = [
     "-alpha",
@@ -76,6 +77,7 @@ def exec_git(
             cwd=fspath(cwd) if cwd else None,
             check=True,
             stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
             encoding="utf8",
             errors="replace",
         )
@@ -575,3 +577,43 @@ class Git:
 
         args.extend(commit)
         return self.exec(*args).splitlines()
+
+    def move(self, old: PathLike, new: PathLike) -> None:
+        """
+        Move a file from old to new
+        """
+        return self.exec("mv", fspath(old), fspath(new))
+
+    def remove(self, to_remove: PathLike) -> None:
+        """
+        Remove a file from git
+        """
+        return self.exec("rm", fspath(to_remove))
+
+    def status(
+        self,
+        files: Optional[Iterable[PathLike]] = None,
+    ) -> Iterator[StatusEntry]:
+        """Get information about the current git status.
+
+        Args:
+            files: specify an iterable of :py:class:`os.PathLike` and
+                exclude all other paths for the status.
+
+        Returns:
+            An iterator of :py:class:`StatusEntry` instances that contain the
+            status of the specific files.
+        """
+        args = [
+            "status",
+            "-z",
+            "--ignore-submodules",
+            "--untracked-files=no",
+        ]
+
+        if files:
+            args.append("--")
+            args.extend([fspath(f) for f in files])
+
+        output = self.exec(*args)
+        return parse_git_status(output)
