@@ -1,4 +1,4 @@
-# Copyright (C) 2022 Greenbone Networks GmbH
+# Copyright (C) 2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -19,4 +19,6 @@ from pontos.errors import PontosError
 
 
 class GitHubApiError(PontosError):
-    """Error while using the GitHub API"""
+    """
+    Error while using the GitHub API
+    """
