@@ -173,9 +173,9 @@ class GitHubAsyncRESTReleases(GitHubAsyncREST):
                         async for content, progress in download:
                             f.write(content)
                             print(progress)
-        """
+        """  # noqa: E501
         api = f"https://github.com/{repo}/archive/refs/tags/{tag}.tar.gz"
-        return download_async(self._client.stream(api))
+        return download_async(self._client.stream(api), url=api)
 
     def download_release_zip(
         self,
@@ -206,9 +206,9 @@ class GitHubAsyncRESTReleases(GitHubAsyncREST):
                         async for content, progress in download:
                             f.write(content)
                             print(progress)
-        """
+        """  # noqa: E501
         api = f"https://github.com/{repo}/archive/refs/tags/{tag}.zip"
-        return download_async(self._client.stream(api))
+        return download_async(self._client.stream(api), url=api)
 
     async def download_release_assets(
         self,
@@ -258,7 +258,7 @@ class GitHubAsyncRESTReleases(GitHubAsyncREST):
                         )
 
                     file_paths = await asyncio.gather(*tasks)
-        """
+        """  # noqa: E501
         release = await self.get(repo, tag)
         assets_url = release.assets_url
         if not assets_url:
@@ -269,13 +269,18 @@ class GitHubAsyncRESTReleases(GitHubAsyncREST):
 
         assets_json = response.json()
         for asset_json in assets_json:
-            asset_url: str = asset_json.get("url", "")
+            # use browser_download_url here because url doesn't response with
+            # exactly the same data on every request.
+            # not getting exactly the same data changes the hash sum.
+            asset_url: str = asset_json.get("browser_download_url", "")
             name: str = asset_json.get("name", "")
 
             if match_pattern and not Path(name).match(match_pattern):
                 continue
 
-            yield name, download_async(self._client.stream(asset_url))
+            yield name, download_async(
+                self._client.stream(asset_url), url=asset_url
+            )
 
     async def upload_release_assets(
         self,
@@ -320,7 +325,7 @@ class GitHubAsyncRESTReleases(GitHubAsyncREST):
                         "foo/bar", "1.2.3", files
                     ):
                         print(f"Uploaded: {uploaded_file}")
-        """
+        """  # noqa: E501
         release = await self.get(repo, tag)
         asset_url = release.upload_url.replace("{?name,label}", "")
 
