@@ -1,4 +1,4 @@
-# Copyright (C) 2022 Greenbone Networks GmbH
+# Copyright (C) 2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -20,9 +20,8 @@
 import os
 from argparse import ArgumentParser, FileType, Namespace
 from pathlib import Path
-from typing import List
+from typing import List, Optional
 
-from pontos.github.api import FileStatus
 from pontos.github.cmds import (
     create_pull_request,
     create_release,
@@ -35,6 +34,7 @@ from pontos.github.cmds import (
     tag,
     update_pull_request,
 )
+from pontos.github.models.base import FileStatus
 from pontos.github.models.organization import RepositoryType
 
 body_template = Path(__file__).parent / "pr_template.md"
@@ -49,7 +49,7 @@ def get_repository_type(rtype: str) -> RepositoryType:
 
 
 def parse_args(
-    args: List[str] = None,
+    args: Optional[List[str]] = None,
 ) -> Namespace:
     """
     Parsing args for Pontos GitHub
