@@ -16,7 +16,17 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from datetime import datetime
-from typing import Any, AsyncIterator, Dict, List, Optional, Union
+from types import TracebackType
+from typing import (
+    Any,
+    AsyncIterator,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Type,
+    Union,
+)
 
 from httpx import Timeout
 
@@ -24,6 +34,7 @@ from pontos.errors import PontosError
 from pontos.nvd.api import (
     DEFAULT_TIMEOUT_CONFIG,
     NVDApi,
+    Params,
     convert_camel_case,
     format_date,
     now,
@@ -162,9 +173,9 @@ class CVEApi(NVDApi):
                     async for cve in api.cves(keywords=["Mac OS X", "kernel"]):
                         print(cve.id)
         """
-        total_results = None
+        total_results: Optional[int] = None
 
-        params = {}
+        params: Params = {}
         if last_modified_start_date:
             params["lastModStartDate"] = format_date(last_modified_start_date)
             if not last_modified_end_date:
@@ -219,7 +230,7 @@ class CVEApi(NVDApi):
         if has_oval:
             params["hasOval"] = ""
 
-        start_index = 0
+        start_index: int = 0
         results_per_page = None
 
         while total_results is None or start_index < total_results:
@@ -235,14 +246,17 @@ class CVEApi(NVDApi):
                 object_hook=convert_camel_case
             )
 
-            results_per_page: int = data["results_per_page"]
-            total_results: int = data["total_results"]
-            vulnerabilities = data.get("vulnerabilities", [])
+            total_results = data["total_results"]  # type: ignore
+            results_per_page: int = data["results_per_page"]  # type: ignore
+            vulnerabilities: Iterable = data.get(  # type: ignore
+                "vulnerabilities", []
+            )
 
             for vulnerability in vulnerabilities:
                 yield CVE.from_dict(vulnerability["cve"])
 
-            start_index += results_per_page
+            if results_per_page is not None:
+                start_index += results_per_page
 
     async def cve(self, cve_id: str) -> CVE:
         """
@@ -280,3 +294,17 @@ class CVEApi(NVDApi):
 
         vulnerability = vulnerabilities[0]
         return CVE.from_dict(vulnerability["cve"])
+
+    async def __aenter__(self) -> "CVEApi":
+        await super().__aenter__()
+        return self
+
+    async def __aexit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_value: Optional[BaseException],
+        traceback: Optional[TracebackType],
+    ) -> Optional[bool]:
+        return await super().__aexit__(  # type: ignore
+            exc_type, exc_value, traceback
+        )
