@@ -18,6 +18,7 @@
 
 import asyncio
 from argparse import Namespace
+from dataclasses import dataclass
 from enum import IntEnum, auto
 from pathlib import Path
 from typing import Optional
@@ -27,6 +28,7 @@ import httpx
 from pontos.changelog.conventional_commits import ChangelogBuilder
 from pontos.errors import PontosError
 from pontos.git import Git
+from pontos.github.actions.core import ActionIO
 from pontos.github.api import GitHubAsyncRESTApi
 from pontos.terminal import Terminal
 from pontos.version import Version, VersionCalculator, VersionError
@@ -37,6 +39,23 @@ from pontos.version.schemes import VersioningScheme
 from .helper import ReleaseType, find_signing_key, get_git_repository_name
 
 
+@dataclass
+class ReleaseInformation:
+    last_release_version: Optional[Version]
+    release_version: Version
+    git_release_tag: str
+    next_version: Version
+
+    def write_github_output(self):
+        with ActionIO.out() as output:
+            output.write(
+                "last-release-version", self.last_release_version or ""
+            )
+            output.write("release-version", self.release_version)
+            output.write("git-release-tag", self.git_release_tag)
+            output.write("next-version", self.next_version)
+
+
 class ReleaseReturnValue(IntEnum):
     """
     Possible return values of ReleaseCommand
@@ -108,7 +127,10 @@ class ReleaseCommand:
         return git_version in git_tags
 
     def _create_changelog(
-        self, release_version: str, last_release_version: str, cc_config: Path
+        self,
+        release_version: Version,
+        last_release_version: Optional[Version],
+        cc_config: Path,
     ) -> str:
         changelog_builder = ChangelogBuilder(
             space=self.space,
@@ -118,7 +140,9 @@ class ReleaseCommand:
         )
 
         return changelog_builder.create_changelog(
-            last_version=last_release_version,
+            last_version=last_release_version.parsed_version
+            if last_release_version
+            else None,
             next_version=release_version,
         )
 
@@ -209,10 +233,10 @@ class ReleaseCommand:
                 else None,
             )
         except PontosError as e:
-            self.terminal.error(
+            last_release_version = None
+            self.terminal.warning(
                 f"Could not determine last release version. {e}"
             )
-            return ReleaseReturnValue.NO_LAST_RELEASE_VERSION
 
         if not last_release_version:
             if not release_version:
@@ -270,10 +294,15 @@ class ReleaseCommand:
                 )
                 return ReleaseReturnValue.UPDATE_VERSION_ERROR
 
-        self.terminal.info(
-            f"Creating changelog for {release_version} since "
-            f"{last_release_version}"
-        )
+        if last_release_version:
+            self.terminal.info(
+                f"Creating changelog for {release_version} since "
+                f"{last_release_version}"
+            )
+        else:
+            self.terminal.info(
+                f"Creating changelog for {release_version} as initial release."
+            )
 
         release_text = self._create_changelog(
             release_version, last_release_version, cc_config
@@ -345,6 +374,15 @@ class ReleaseCommand:
             self.terminal.info("Pushing changes")
             self.git.push(follow_tags=True, remote=git_remote_name)
 
+        self.release_information = ReleaseInformation(
+            last_release_version=last_release_version,
+            release_version=release_version,
+            git_release_tag=git_version,
+            next_version=next_version,
+        )
+        if ActionIO.has_output():
+            self.release_information.write_github_output()
+
         return ReleaseReturnValue.SUCCESS
 
 
