@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Greenbone Networks GmbH
+# Copyright (C) 2021-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -15,6 +15,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from .null import NullTerminal
+from .rich import RichTerminal
 from .terminal import Terminal
 
-__all__ = ["Terminal"]
+__all__ = (
+    "Terminal",
+    "NullTerminal",
+    "RichTerminal",
+)
