@@ -50,7 +50,7 @@ class ConsoleTestCase(unittest.TestCase):
             title="Foo Bar",
         )
         print_mock.assert_called_once_with(
-            "::warning file=bar,line=123,endLine=234,col=1,endColumn=2,title=Foo Bar::foo"  # pylint: disable=line-too-long
+            "::warning file=bar,line=123,endLine=234,col=1,endColumn=2,title=Foo Bar::foo"  # pylint: disable=line-too-long # noqa: E501
         )
 
     def test_error(self, print_mock):
@@ -64,7 +64,7 @@ class ConsoleTestCase(unittest.TestCase):
             title="Foo Bar",
         )
         print_mock.assert_called_once_with(
-            "::error file=bar,line=123,endLine=234,col=1,endColumn=2,title=Foo Bar::foo"  # pylint: disable=line-too-long
+            "::error file=bar,line=123,endLine=234,col=1,endColumn=2,title=Foo Bar::foo"  # pylint: disable=line-too-long # noqa: E501
         )
 
     def test_notice(self, print_mock):
@@ -78,7 +78,7 @@ class ConsoleTestCase(unittest.TestCase):
             title="Foo Bar",
         )
         print_mock.assert_called_once_with(
-            "::notice file=bar,line=123,endLine=234,col=1,endColumn=2,title=Foo Bar::foo"  # pylint: disable=line-too-long
+            "::notice file=bar,line=123,endLine=234,col=1,endColumn=2,title=Foo Bar::foo"  # pylint: disable=line-too-long # noqa: E501
         )
 
     def test_log(self, print_mock):
@@ -119,14 +119,45 @@ class ActionIOTestCase(unittest.TestCase):
 
                 self.assertEqual(output, "foo=bar\nlorem=ipsum\n")
 
+    @patch.dict("os.environ", {}, clear=True)
     def test_output_no_env(self):
-        with patch.dict("os.environ", {}, clear=True), self.assertRaises(
-            GitHubActionsError
-        ):
+        with self.assertRaises(GitHubActionsError):
             ActionIO.output("foo", "bar")
 
+    @patch.dict("os.environ", {"GITHUB_OUTPUT": ""}, clear=True)
     def test_output_empty_env(self):
-        with patch.dict(
-            "os.environ", {"GITHUB_OUTPUT": ""}, clear=True
-        ), self.assertRaises(GitHubActionsError):
+        with self.assertRaises(GitHubActionsError):
             ActionIO.output("foo", "bar")
+
+    @patch.dict("os.environ", {}, clear=True)
+    def test_no_github_output(self):
+        self.assertFalse(ActionIO.has_output())
+
+    @patch.dict(
+        "os.environ", {"GITHUB_OUTPUT": "/foo/github.output"}, clear=True
+    )
+    def test_has_github_output(self):
+        self.assertTrue(ActionIO.has_output())
+
+    def test_out(self):
+        with temp_directory() as temp_dir:
+            outfile = temp_dir / "github.output"
+            with patch.dict(
+                "os.environ",
+                {"GITHUB_OUTPUT": str(outfile.absolute())},
+                clear=True,
+            ):
+                with ActionIO.out() as output:
+                    output.write("foo", "bar")
+
+            self.assertEqual(outfile.read_text(encoding="utf8"), "foo=bar\n")
+
+    @patch.dict("os.environ", {}, clear=True)
+    def test_out_failure(self):
+        with self.assertRaisesRegex(
+            GitHubActionsError,
+            "GITHUB_OUTPUT environment variable not set. Can't write "
+            "action output.",
+        ):
+            with ActionIO.out():
+                pass
