@@ -16,6 +16,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=redefined-builtin,disallowed-name
+# ruff: noqa: E501
 
 import unittest
 from enum import Enum
@@ -100,7 +101,7 @@ class AsyncDownloadProgressIterableTestCase(IsolatedAsyncioTestCase):
 
 class DownloadAsyncTestCase(IsolatedAsyncioTestCase):
     async def test_download_async(self):
-        response = create_response()
+        response = create_response(url="http://some.url")
         response.aiter_bytes.return_value = AsyncIteratorMock(["1", "2"])
         stream = AsyncMock()
         stream.__aenter__.return_value = response
@@ -108,6 +109,8 @@ class DownloadAsyncTestCase(IsolatedAsyncioTestCase):
         async with download_async(
             stream, content_length=2
         ) as download_iterable:
+            self.assertEqual(download_iterable.url, "http://some.url")
+
             it = aiter(download_iterable)
             content, progress = await anext(it)
 
@@ -119,13 +122,38 @@ class DownloadAsyncTestCase(IsolatedAsyncioTestCase):
             self.assertEqual(progress, 100)
 
     async def test_download_async_content_length(self):
-        response = create_response(headers=MagicMock())
+        response = create_response(headers=MagicMock(), url="http://some.url")
         response.aiter_bytes.return_value = AsyncIteratorMock(["1", "2"])
         response.headers.get.return_value = 2
         stream = AsyncMock()
         stream.__aenter__.return_value = response
 
         async with download_async(stream) as download_iterable:
+            self.assertEqual(download_iterable.url, "http://some.url")
+
+            it = aiter(download_iterable)
+            content, progress = await anext(it)
+
+            self.assertEqual(content, "1")
+            self.assertEqual(progress, 50)
+
+            content, progress = await anext(it)
+            self.assertEqual(content, "2")
+            self.assertEqual(progress, 100)
+
+    async def test_download_async_url(self):
+        response = create_response(url="http://some.url")
+        response.aiter_bytes.return_value = AsyncIteratorMock(["1", "2"])
+        stream = AsyncMock()
+        stream.__aenter__.return_value = response
+
+        async with download_async(
+            stream,
+            url="http://foo.bar",
+            content_length=2,
+        ) as download_iterable:
+            self.assertEqual(download_iterable.url, "http://foo.bar")
+
             it = aiter(download_iterable)
             content, progress = await anext(it)
 
@@ -485,13 +513,13 @@ class AddSysPathTestCase(unittest.TestCase):
     def test_add_sys_path(self):
         with self.assertRaises(ImportError):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
-            import mymodule
+            import mymodule  # noqa: F811,F401
 
         with temp_file("", name="mymodule.py") as module_path, add_sys_path(
             module_path.parent
         ):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
-            import mymodule
+            import mymodule  # noqa: F811,F401
 
         unload_module("mymodule")
 
@@ -502,11 +530,11 @@ class EnsureUnloadModuleTestCase(unittest.TestCase):
             "def foo():\n  pass", name="bar"
         ), ensure_unload_module("bar"):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
-            import bar
+            import bar  # noqa: F401,F811
 
         with self.assertRaises(ImportError):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
-            import bar
+            import bar  # noqa: F401,F811
 
     def test_ensure_unload_module_exception(self):
         with self.assertRaisesRegex(ValueError, "Ipsum"):
@@ -525,14 +553,14 @@ class EnsureUnloadModuleTestCase(unittest.TestCase):
     def test_add_sys_path_exception(self):
         with self.assertRaises(ImportError):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
-            import mymodule
+            import mymodule  # noqa: F811,F401
 
         try:
             with temp_file("", name="mymodule.py") as module_path, add_sys_path(
                 module_path.parent
             ):
                 # pylint: disable=import-error,import-outside-toplevel,unused-import
-                import mymodule
+                import mymodule  # noqa: F811,F401
 
                 raise ValueError()
         except ValueError:
@@ -542,7 +570,7 @@ class EnsureUnloadModuleTestCase(unittest.TestCase):
 
         with self.assertRaises(ImportError):
             # pylint: disable=import-error,import-outside-toplevel,unused-import
-            import mymodule
+            import mymodule  # noqa: F401,F811
 
 
 class SnakeCaseTestCase(unittest.TestCase):
