@@ -20,10 +20,11 @@ import unittest
 from unittest.mock import patch
 
 from pontos import main
+from pontos.version import __version__
 
 
 class TestPontos(unittest.TestCase):
-    @patch("pontos.pontos.ConsoleTerminal")
+    @patch("pontos.pontos.RichTerminal")
     def test_pontos(self, terminal_mock):
         main()
 
@@ -35,3 +36,12 @@ class TestPontos(unittest.TestCase):
             'Use the listed commands "help" for more information '
             "and arguments description."
         )
+
+    @patch("pontos.pontos.RichTerminal")
+    @patch("sys.argv", ["pontos", "--version"])
+    def test_pontos_version(self, terminal_mock):
+        main()
+
+        terminal_mock.return_value.print.assert_called_once_with(
+            f"pontos version {__version__}"
+        )
